<?php

namespace EventPortal\Domain\Util\QuickButtons;

use EventPortal\Domain\Component\Button;
use Illuminate\Support\Arr;

class QuickButtons
{
    /** @var string */
    public $name;

    /** @var array */
    public $buttons = [];

    /** @var array */
    private $context = [];

    public function __construct(string $name)
    {
        $this->name = $name;
    }

    public function addButtons(callable $buttons): self
    {
        $this->buttons[] = $buttons;

        return $this;
    }

    public function get(): array
    {
        $this->resolve();

        return $this->buttons;
    }

    /**
     * @param mixed ...$models
     */
    public function context(...$models): self
    {
        $keyedModels = [];

        foreach ($models as $model) {
            $keyedModels[$model::KEY] = $model;
        }

        $this->context = $keyedModels;

        return $this;
    }

    private function resolve(): void
    {
        if ($this->buttons === []) {
            return;
        }

        $this->buttons = collect($this->buttons)
            ->flatMap(function (callable $button) {
                return app()->call($button, Arr::wrap($this->context));
            })
            ->map(function (Button $button) {
                if ($button->modal) {
                    $button->modal = $button->modal->get();
                }

                return $button;
            })
            ->toArray();
    }
}
