<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Permission\Models\Group;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\Permission\Resources\Group as GroupResource;
use EventPortal\Domain\Util\AdminRender;
use EventPortal\Enums\InertiaMethod;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Illuminate\Support\Collection;
use Inertia\Response;

class PermissionController extends Controller
{
    public function __construct()
    {
        $this->middleware('check-permission:permission.update')->only('update');
    }

    public function index(): Response
    {
        $roles = Role::withoutSuperAdmin()->get();

        $columns = Arr::collapse($roles->map(static function (Role $role) {
            return [$role->name => $role->label];
        }));

        $data = Group::with('permissions')
            ->get(['id', 'name', 'label'])
            ->map(static function (Group $group) use ($roles): array {
                return (new GroupResource($group, $roles))->toArray();
            });

        $quickButton = Button::make('Create role')
            ->method(InertiaMethod::VISIT())
            ->icon('plus')
            ->route('admin.role.create');

        return AdminRender::component('Admin/Permission/Index')
            ->key('permission.index')
            ->withData(compact('columns', 'data'))
            ->withQuickButton($quickButton, has_permission('role.store'))
            ->get();
    }

    public function update(Request $request): RedirectResponse
    {
        $data = collect($request->all());

        $data->groupBy('roleId')->each(static function (Collection $groupedByRole, string $roleName): void {
            $role = Role::where('name', $roleName)->firstOrFail();
            $groupedByRole->groupBy('selected')
                ->each(static function (Collection $groupedBySelected, bool $selected) use ($role): void {
                    if ($selected === true) {
                        $role->givePermissionTo($groupedBySelected->pluck('permissionId')->toArray());
                        return;
                    }

                    $role->revokePermissionTo($groupedBySelected->pluck('permissionId')->toArray());
                });
        });

        toast()->success(trans('permission.updated'));

        return redirect()->route('admin.permission.index');
    }
}
