<?php

namespace EventPortal\Tests\Unit\Approval\Models;

use EventPortal\Domain\Approval\Models\Approval;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

/**
 * @group ApprovalModel
 */
class ApprovalTest extends TestCase
{
    use RefreshDatabase;

    /** @test */
    public function event_was_approved_more_than_three_days_ago(): void
    {
        config(['audit.console' => true]); // This needs to be before create, or no update audit is created

        $approval = factory(Approval::class)->state('approved')->create(
            [
                'updated_at' => now()->subDays(5),
                'created_at' => now()->subDays(6),
            ]
        );

        $this->assertFalse($approval->approvedAndRelevant());
    }

    /** @test */
    public function event_was_approved_less_than_three_days_ago(): void
    {
        config(['audit.console' => true]); // This needs to be before create, or no update audit is created

        $approval = factory(Approval::class)->state('approved')->create(
            [
                'updated_at' => now()->subDays(2),
                'created_at' => now()->subDays(1),
            ]
        );

        $this->assertTrue($approval->approvedAndRelevant());
    }

    /** @test */
    public function event_is_not_in_approved_state_but_date_is_less_than_three_days(): void
    {
        config(['audit.console' => true]); // This needs to be before create, or no update audit is created

        $approval = factory(Approval::class)->state('awaiting-approval')->create(
            [
                'updated_at' => now()->subDays(2),
                'created_at' => now()->subDays(1),
            ]
        );

        $this->assertFalse($approval->approvedAndRelevant());
    }

    /** @test */
    public function event_is_not_in_approved_state_but_date_is_greater_than_three_days(): void
    {
        config(['audit.console' => true]); // This needs to be before create, or no update audit is created

        $approval = factory(Approval::class)->state('awaiting-approval')->create(
            [
                'updated_at' => now()->subDays(5),
                'created_at' => now()->subDays(4),
            ]
        );

        $this->assertFalse($approval->approvedAndRelevant());
    }
}
