<?php

namespace EventPortal\Tests\Unit\Component;

use EventPortal\Domain\Component\Input\Text;
use EventPortal\Tests\TestCase;

class ComponentTest extends TestCase
{
    /** @test **/
    public function can_have_something_optionally_set()
    {
        $component = Text::make('Email Address');

        $this->assertNull($component->value);

        $component->when(true, function (Text $text): void {
            $text->value('fadhill@example.com');
        });

        $this->assertEquals('fadhill@example.com', $component->value);
    }

    /** @test **/
    public function can_have_not_set_when_false()
    {
        $component = Text::make('Email Address');

        $this->assertNull($component->value);

        $component->when(false, function (Text $text): void {
            $text->value('fadhill@example.com');
        });

        $this->assertNull($component->value);
    }

    /** @test **/
    public function can_mark_as_gdpr_as_true(): void
    {
        $component = Text::make('text 1')->gdpr();

        $this->assertTrue($component->gdpr);
    }

    /** @test **/
    public function gdpr_is_set_to_false_by_default(): void
    {
        $component = Text::make('text 1');

        $this->assertFalse($component->gdpr);
    }

    public function can_add_help_text(): void
    {
        $helpText = 'This is an example help text';
        $component = Text::make('text 1')->helpText($helpText);

        $this->assertEquals($helpText, $component->helpText);
    }
}
